@@ -18,7 +18,7 @@ class GitRemoteBook(object):
         remote_path = self.get_remote_path()
         local_path = self.local_dir + "/" + remote_path
         if remote_path.startswith("/"):
-            local_path = local_dir + remote_path
+            local_path = self.local_dir + remote_path
         print("local_path is %s"%local_path)
         return local_path
         
